/*!
 * \file    adc.c
 * \brief   Simple driver MPR083 using I2C
 * \version $Revision: 1.2 $
 * \author  Anthony Huereca
 *  2011/2 change CFV2 to CFV1 By Fujisekk LTD

 */
 #include <MCF51JM128.h>
 #include "adc.h"


/*******************************************************************/
/*!
 * Perform an IIR filter on X, Y, and Z axis
 */
void filter_data()
{
byte i;
dword X, Y, Z;

  X = x.reading[samp];
  Y = y.reading[samp];
  Z = z.reading[samp];
  
  for (i=samp;i>0;i--){
    X = (X + ((x.reading[i] + x.result[i-1])>>1))>>1;
    Y = (Y + ((y.reading[i] + y.result[i-1])>>1))>>1;
    Z = (Z + ((z.reading[i] + z.result[i-1])>>1))>>1;
  }
  
  x.result[samp] = (word)X;
  y.result[samp] = (word)Y;
  z.result[samp] = (word)Z;
}

/*******************************************************************/
/*!
 * Get Average from ADC outputs
 * Calculates ADC value for x, y, and z axis.
 */
void avg_data()
{
  byte j;
  long x_avg=0, y_avg=0, z_avg=0;
  
  for(j=1;j<max;j++) 
  {  
    // Read acceleration data
    x_avg +=  (dword)(ReadADC(0x04)<<4);  // Select ADC4 (x-axis) channel
    y_avg +=  (dword)(ReadADC(0x05)<<4);  // Select ADC5 (y-axis) channel 
    z_avg +=  (dword)(ReadADC(0x06)<<4);  // Select ADC6 (z-axis) channel
  }
 
  x.result[0] = (word)(x_avg>>4);
  y.result[0] = (word)(y_avg>>4);
  z.result[0] = (word)(z_avg>>4); 
}

/*******************************************************************/
/* ADC Clock ON */
void initADC(void){
int i;
		  /* Turn on ADC Clock */
	  SCGC1_ADC=1;

    /* Configure ADC since reset when turned clock off */
  /*  Bus clock as clock source, 12-bit conversion and divisor=4  */
  ADCCFG = 0x44;
		
     /* Delay to allow time for accel chip to wake up */
      for(i=0;i<3000;i++)
        {
           asm("nop");
		}
}
/*******************************************************************/
/*!
 * Put accelerometer into sleep mode and turn off ADC clock
 */
void ADC_Off()
{
 
  /* Turn off ADC Clock */ 
  SCGC1_ADC=0;
}

/*
 *
 *
 * @return ADC Value
 */
word readADC(byte channel)
{
  word adc;
  ADCSC1 = channel; 
  while (!(ADCSC1_COCO)){}              // Waits until ADC conversion is completed

  adc=ADCR;
  return adc;
   
}


